#!/bin/bash

PATH="/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"

INSTALLED_PREFIX="Installed: "
CANDIDATE_PREFIX="Candidate: "

mount | grep " on / " | grep rw || {
    NEEDS_REMOUNT=true
    mount -o remount,rw /
}

apt-get update -y
INSTALLED_VERSION=$(apt-cache policy dump978-fr24 | grep "$INSTALLED_PREFIX" | sed "s/[[:blank:]]*${INSTALLED_PREFIX}[[:blank:]]*//")
CANDIDATE_VERSION=$(apt-cache policy dump978-fr24 | grep "$CANDIDATE_PREFIX" | sed "s/[[:blank:]]*${CANDIDATE_PREFIX}[[:blank:]]*//")

echo "Installed version: $INSTALLED_VERSION"
echo "Latest available: $CANDIDATE_VERSION"

# will show dump978-fr24 in the list if previous installation failed
PROBLEMS=$(dpkg --audit dump978-fr24 | grep dump978-fr24)

if [[ "$INSTALLED_VERSION" != "$CANDIDATE_VERSION" || "$PROBLEMS" != "" ]]
then
    echo "Upgrading dump978-fr24 from $INSTALLED_VERSION to $CANDIDATE_VERSION..."
    echo "Waiting for dump978-fr24 to stop completely..."
    systemctl stop dump978-fr24

    PID=$(pidof dump978-fr24)
    if [ -n "$PID" ]; then
        sleep 30
        pkill -9 -P "$PID"
        kill -9 "$PID"
    fi

    DEBIAN_FRONTEND=noninteractive dpkg --force-confdef --force-confold --configure dump978-fr24 || true
    DEBIAN_FRONTEND=noninteractive apt-get -o Dpkg::Options::="--force-confdef" -o Dpkg::Options::="--force-confold" install -y dump978-fr24 || echo "Failed to update, restarting current version..."
    systemctl restart dump978-fr24
else
    echo "Latest version is already installed"
fi

if [ "${NEEDS_REMOUNT}" = true ]; then
    mount -o remount,ro / || echo "Could not remount to read-only"
fi
